@@ -92,6 +92,10 @@ class Iterator(object):
         self.results.reverse()
         self.reset()
 
+    def __reversed__(self):
+        self.reverse()
+        return self
+
     def sort(self, *args, **kwargs):
         """list interface compatibility"""
         self.results.sort(*args, **kwargs)
@@ -465,6 +469,10 @@ class Query(object):
     def has_bounds(self):
         return len(self.bounds) > 0
 
+    def has_limit(self):
+        limit = self.bounds.get('limit', 0)
+        return limit > 0
+
     def get(self, limit=None, page=None):
         """
         get results from the db
